==> system-monitoring-center-v1.2.1.tar.bz2: system-monitoring-center-v1.2.1/README.md <==
# System Monitoring Center

GTK3 and Python 3 based, system performance and usage monitoring tool.


<p align="center">
<a href="https://github.com/hakandundar34coding/system-monitoring-center/releases"><img alt="Platform (GNU/Linux)" src="https://img.shields.io/badge/platform-GNU/Linux-blue.svg"/>
</a>
<a href="https://sourceforge.net/projects/system-monitoring-center/files"><img alt="Download System Monitoring Center" src="https://img.shields.io/sourceforge/dt/system-monitoring-center.svg" ></a>
</a>
<a href="https://github.com/hakandundar34coding/system-monitoring-center/releases"><img alt="GitHub all releases" src="https://img.shields.io/github/downloads/hakandundar34coding/system-monitoring-center/total"></a>
</a>
<a href="https://github.com/hakandundar34coding/system-monitoring-center/releases"><img alt="GitHub release (latest by date)" src="https://img.shields.io/github/v/release/hakandundar34coding/system-monitoring-center"></a>
</a>
</p>


<a href="https://github.com/hakandundar34coding/system-monitoring-center/releases/latest"><img alt="Download System Monitoring Center" src="https://img.shields.io/badge/Download%20Now-Debian%20|%20RPM%20|%20pacman-brightgreen?style=for-the-badge"></a>
</a>

<a href="https://repology.org/project/system-monitoring-center/versions">
    <img src="https://repology.org/badge/vertical-allrepos/system-monitoring-center.svg" alt="Packaging status">
</a>

### Generating Packages From Source Code:
```
1) Download the source code
2) Browse /packaging_scripts folder
3) Open terminal in this folder
4) Run the required script without "sudo"
   Command:
   sh [script file name].sh

Note: If there are uninstalled dependency problems during installation:
      Try installing the application after installing the dependencies.

Note2: For RPM based distributions:
       Generate RPM package by using the installation script and install it,
       if the application is not run after installation of the downloaded RPM package.
```

### Features:
* Detailed system performance and usage usage monitoring/managing features:
    * Monitoring CPU, RAM, Disk, Network, GPU hardware information/performance/usage
    * An always on top and semi-transparent floating summary window for performance monitoring
    * Monitoring and managing processes, users, startup applications and services (systemd)
    * Monitoring sensors and general system information
* Language support (more languages will be added if translations are provided by contributors):
    * English, Turkish
* Adapts to system theme
* Free and open sourced



![System Monitoring Center](screenshots/cpu_tab_dark_system_theme.png)

![System Monitoring Center](screenshots/cpu_tab_white_system_theme.png)

![System Monitoring Center](screenshots/cpu_tab_per_core_dark_system_theme.png)

![System Monitoring Center](screenshots/network_tab_dark_system_theme.png)

![System Monitoring Center](screenshots/gpu_tab_dark_system_theme.png)

![System Monitoring Center](screenshots/sensors_tab_dark_system_theme.png)

![System Monitoring Center](screenshots/processes_list_view_dark_system_theme.png)

![System Monitoring Center](screenshots/startup_tab_dark_system_theme.png)

![System Monitoring Center](screenshots/services_tab_dark_system_theme.png)

![System Monitoring Center](screenshots/system_tab_dark_system_theme.png)


### Dependencies:
* Python 3 (Programming language)
* GTK3 (GUI)
* python3-opengl (for FPS counting)

==> system-monitoring-center-v1.7.0.tar.bz2: system-monitoring-center-v1.7.0/README.md <==
# System Monitoring Center

GTK3 and Python 3 based, system performance and usage monitoring tool.


<p align="center">
<a href="https://github.com/hakandundar34coding/system-monitoring-center/releases"><img alt="Platform (GNU/Linux)" src="https://img.shields.io/badge/platform-GNU/Linux-blue.svg"/>
</a>
<a href="https://github.com/hakandundar34coding/system-monitoring-center/releases"><img alt="Download System Monitoring Center" src="https://img.shields.io/sourceforge/dt/system-monitoring-center.svg" ></a>
</a>
<a href="https://github.com/hakandundar34coding/system-monitoring-center/releases"><img alt="GitHub all releases" src="https://img.shields.io/github/downloads/hakandundar34coding/system-monitoring-center/total"></a>
</a>
<a href="https://github.com/hakandundar34coding/system-monitoring-center/releases"><img alt="GitHub release (latest by date)" src="https://img.shields.io/github/v/release/hakandundar34coding/system-monitoring-center"></a>
</a>
</p>


<a href="https://github.com/hakandundar34coding/system-monitoring-center/releases"><img alt="Download System Monitoring Center" src="https://img.shields.io/badge/Download%20Now-Debian%20|%20RPM%20|%20pacman-brightgreen?style=for-the-badge"></a>
</a>

<a href="https://repology.org/project/system-monitoring-center/versions">
    <img src="https://repology.org/badge/vertical-allrepos/system-monitoring-center.svg" alt="Packaging status">
</a>

### Generating Packages From Source Code:
```
1) Download the source code
2) Browse /packaging_scripts folder
3) Open terminal in this folder
4) Run the required script without "sudo"
   For DEB package:
      sh debian_packaging.sh
   For RPM package:
      sh rpm_packaging.sh
   For PACMAN package:
      sh arch_linux_packaging.sh

Note: If there are dependency problems during installation:
      1) Install the dependencies 
      2) Install the application
```

### Features:
* Detailed system performance and usage usage monitoring/managing features:
    * Monitoring CPU, RAM, Disk, Network, GPU hardware information/performance/usage
    * An always on top and semi-transparent floating summary window for performance monitoring
    * Monitoring and managing processes, users, startup applications and services (systemd)
    * Monitoring sensors and general system information
* Language support:
    * Brazilian Portuguese, Czech, English, Polish (initial), Turkish
    * More languages will be added if translations are provided by contributors
* Adapts to system theme
* Free and open sourced



![System Monitoring Center](screenshots/cpu_tab_dark_system_theme.png)

![System Monitoring Center](screenshots/cpu_tab_white_system_theme.png)

![System Monitoring Center](screenshots/cpu_tab_per_core_dark_system_theme.png)

![System Monitoring Center](screenshots/network_tab_dark_system_theme.png)

![System Monitoring Center](screenshots/gpu_tab_dark_system_theme.png)

![System Monitoring Center](screenshots/sensors_tab_dark_system_theme.png)

![System Monitoring Center](screenshots/processes_list_view_dark_system_theme.png)

![System Monitoring Center](screenshots/startup_tab_dark_system_theme.png)

![System Monitoring Center](screenshots/services_tab_dark_system_theme.png)

![System Monitoring Center](screenshots/system_tab_dark_system_theme.png)


### Note:
* A simple FPS counter is shown on the GPU tab and may not be accurate in some situations.
* FPS counting does not continue when window is minimized.
